@@ -6,7 +6,8 @@ import time
 from typing import Optional, Any, Callable, List, Dict, Union, Iterable
 
 import pyvisa
-from pymodbus.client.sync import ModbusTcpClient as ModbusClient
+from pyvisa.constants import StopBits
+from pymodbus.client import ModbusTcpClient as ModbusClient
 
 from .hooks import create_converter, call_hooks
 
@@ -567,7 +568,7 @@ class Instrument:
     def config_serial(
         self,
         baud_rate: Optional[int] = None,
-        stop_bits: Optional[int] = None,
+        stop_bits: Optional[StopBits] = None,
         data_bits: Optional[int] = None,
         parity: Optional[int] = None,
     ) -> None:
@@ -640,6 +641,14 @@ class Instrument:
                 break
         return data
 
+    def query_serial(self, command, delay):
+        self.device.write(command)
+        time.sleep(inst_delay)
+        reply = self.device.read(
+            termination=(self.read_termination or self._termination)
+        )
+        return reply
+
     @ensure_online
     def query(self, command: str, delay: Optional[float] = None):
         """Query the insturment directly."""
@@ -657,12 +666,8 @@ class Instrument:
 
                 if delay is not None:
                     inst_delay = delay
+                self.query_serial(command, delay)
 
-                self.device.write(command)
-                time.sleep(inst_delay)
-                reply = self.device.read(
-                    termination=(self.read_termination or self._termination)
-                )
             elif self.connection_type == Instrument.SOCKET:
                 self.device.sendall(bytes(command + self._termination, self._encoding))
                 reply_bytes = Instrument._recvall(self.device)
