@@ -4,7 +4,7 @@
 
 from .Dataset import Dataset
 from .App import App
-from .Instrument import Instrument
+from .Instrument import Instrument, StopBits
 from .HCMainWindow import HCMainWindow
 from .logging import setup_logging, setup_logging_docopt
 from .ZMQAdapter import ZMQAdapter
