@@ -12,7 +12,7 @@ import logging
 from typing import Dict, Optional, Union, Callable, Any, List
 import pkg_resources
 
-from PyQt5.QtWidgets import (
+from PyQt6.QtWidgets import (
     QGridLayout,
     QPushButton,
     QLabel,
@@ -22,8 +22,8 @@ from PyQt5.QtWidgets import (
     QSpinBox,
     QSizePolicy,
 )
-from PyQt5.QtGui import QPixmap, QIcon, QDoubleValidator, QFont, QFontMetrics
-from PyQt5 import QtCore
+from PyQt6.QtGui import QPixmap, QIcon, QDoubleValidator, QFont, QFontMetrics
+from PyQt6 import QtCore
 from ...base.hooks import call_hooks
 
 
@@ -73,22 +73,27 @@ def convert_prefix(value: str, decimals: int = 3) -> List[str]:
 class HCGridLayout(QGridLayout):
     """Places HCwidgets into a Gridlayout.
 
-    This is a 2 column grid with the label of the HCWidget in the left
+    This is a 2*columns (columns=1 by default) column grid with the label of the HCWidget in the left
     column and the widget itself in the right column.
 
     A special case is a HCDoubleSpinComboBox where an additional 3rd
     column is created.
     """
 
-    def __init__(self, HCwidgets: List, offset: int = 0) -> None:
+    def __init__(self, HCwidgets: List, offset: int = 0, columns: int = 1) -> None:
         super().__init__()
+        has_double_spin = any(isinstance(w, HCDoubleSpinComboBox) for w in HCwidgets)
+        width = 3 if has_double_spin else 2
+
         for i, w in enumerate(HCwidgets):
-            self.addWidget(w.label, i + offset, 0)
+            col = i % columns
+            row = i // columns
+            self.addWidget(w.label, row + offset, 0 + col * width)
             if isinstance(w, HCDoubleSpinComboBox):
-                self.addWidget(w.spin, i + offset, 1)
-                self.addWidget(w.combo, i + offset, 2)
+                self.addWidget(w.spin, row + offset, 1 + col * width)
+                self.addWidget(w.combo, row + offset, 2 + col * width)
             else:
-                self.addWidget(w, i + offset, 1)
+                self.addWidget(w, row + offset, 1 + col * width)
 
 
 class HCMixin:
@@ -100,6 +105,23 @@ class HCMixin:
     since there might be custom code needed to do this.
 
     HCwidgets generally inherit from this class.
+
+    Any parameter listed here will be automatically added to the app's
+    auto_update list
+
+    Parameters
+    ----------
+    app
+       The main app
+    instrument
+       The name of the instrument
+    parameter
+       The name of the parameter
+    auto_update
+       Should the variable be added to the auto_update function. Set this
+       to `False` in case you want to run this on a different schedule. In this
+       case you need to create your own timer though and call the appropiate
+       update function.
     """
 
     def __init__(self, **kwargs) -> None:
@@ -107,6 +129,7 @@ class HCMixin:
         app = kwargs.pop("app")
         instrument = kwargs.pop("instrument")
         parameter = kwargs.pop("parameter")
+        auto_update = kwargs.pop("auto_update", True)
 
         self._visible = app.is_parameter(instrument, parameter)
 
@@ -134,15 +157,25 @@ class HCMixin:
         self.label = QLabel(label)
 
         if label_align == "right":
-            self.label.setAlignment(QtCore.Qt.AlignRight | QtCore.Qt.AlignVCenter)
+            self.label.setAlignment(
+                QtCore.Qt.AlignmentFlag.AlignRight
+                | QtCore.Qt.AlignmentFlag.AlignVCenter
+            )
         elif label_align == "left":
-            self.label.setAlignment(QtCore.Qt.AlignLeft | QtCore.Qt.AlignVCenter)
+            self.label.setAlignment(
+                QtCore.Qt.AlignmentFlag.AlignLeft | QtCore.Qt.AlignmentFlag.AlignVCenter
+            )
         elif label_align == "center":
-            self.label.setAlignment(QtCore.Qt.AlignCenter | QtCore.Qt.AlignVCenter)
+            self.label.setAlignment(
+                QtCore.Qt.AlignmentFlag.AlignCenter
+                | QtCore.Qt.AlignmentFlag.AlignVCenter
+            )
 
         if self._visible:
             # connect to app
             self.app.add_widget(self.instrument, self.parameter, self)
+            if auto_update:
+                self.app.add_auto_update_instrument_parameter(instrument, parameter)
         else:
             # hide widget, put parameter on list to skip when auto-updating
             logger.info(
@@ -211,6 +244,7 @@ class HCLabel(HCMixin, QLabel):
         use_prefix: bool = True,
         label_align: str = "left",
         min_width: int = 10,
+        auto_update=True,
     ) -> None:
 
         super().__init__(
@@ -220,6 +254,7 @@ class HCLabel(HCMixin, QLabel):
             label=label,
             label_align=label_align,
             text="",
+            auto_update=auto_update,
         )
         self.unit = unit
         self.use_prefix = use_prefix
@@ -265,6 +300,7 @@ class HCLineEdit(HCMixin, QLineEdit):
         return_set_value: bool = False,
         default_txt: str = "----",
         validator=QDoubleValidator,
+        auto_update=True,
     ):
         super().__init__(
             app=app,
@@ -272,6 +308,7 @@ class HCLineEdit(HCMixin, QLineEdit):
             parameter=parameter,
             label=label,
             label_align=label_align,
+            auto_update=auto_update,
         )
         self.validator = validator
         self.return_set_value = return_set_value
@@ -302,7 +339,13 @@ class HCDoubleSpinBox(HCMixin, QDoubleSpinBox):
     """A simple control widget with a label (QLabel) and an input box (QDoubleSpinBox)."""
 
     def __init__(
-        self, app, instrument: str, parameter: str, label: str, label_align="left"
+        self,
+        app,
+        instrument: str,
+        parameter: str,
+        label: str,
+        label_align="left",
+        auto_update=True,
     ):
         super().__init__(
             app=app,
@@ -310,6 +353,7 @@ class HCDoubleSpinBox(HCMixin, QDoubleSpinBox):
             parameter=parameter,
             label=label,
             label_align=label_align,
+            auto_update=auto_update,
         )
 
         self.setValue(0)
@@ -334,6 +378,7 @@ class HCPushButton(HCMixin, QPushButton):
         parameter: str,
         label: str = "",
         label_align: str = "left",
+        auto_update=True,
     ):
         super().__init__(
             app=app,
@@ -342,6 +387,7 @@ class HCPushButton(HCMixin, QPushButton):
             label=label,
             label_align=label_align,
             text=label,
+            auto_update=auto_update,
         )
 
         self.clicked.connect(self.value_change)
@@ -389,6 +435,7 @@ class HCOnOffButton(HCMixin, QPushButton):
         icon_checked: str = "button-power-on.svg",
         icon_unchecked: str = "button-power-off.svg",
         show_set_text: bool = False,
+        auto_update=True,
     ):
         super().__init__(
             app=app,
@@ -397,6 +444,7 @@ class HCOnOffButton(HCMixin, QPushButton):
             label=label,
             label_align=label_align,
             colon=False,
+            auto_update=auto_update,
         )
 
         self.show_icon = show_icon
@@ -493,9 +541,14 @@ class HCOnOffIndicator(HCMixin, QLabel):
         icon_checked: str = "on-off-indicator-on.svg",
         icon_unchecked: str = "on-off-indicator-off.svg",
         tooltip: str = "",
+        auto_update=True,
     ):
         super().__init__(
-            app=app, instrument=instrument, parameter=parameter, text=label
+            app=app,
+            instrument=instrument,
+            parameter=parameter,
+            text=label,
+            auto_update=auto_update,
         )
 
         self.label = QLabel(label)
@@ -517,7 +570,7 @@ class HCOnOffIndicator(HCMixin, QLabel):
         self.setMouseTracking(True)
         self.setToolTip(tooltip)
 
-        self.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
+        self.setSizePolicy(QSizePolicy.Policy.Fixed, QSizePolicy.Policy.Fixed)
 
     def sizeHint(self):
         if self.show_icon and not self.show_text:
@@ -573,6 +626,7 @@ class HCComboBox(HCMixin, QComboBox):
         label_align: str = "left",
         lookuptable: Optional[Dict] = None,
         upper: bool = False,
+        auto_update=True,
     ):
         super().__init__(
             app=app,
@@ -580,6 +634,7 @@ class HCComboBox(HCMixin, QComboBox):
             parameter=parameter,
             label=label,
             label_align=label_align,
+            auto_update=auto_update,
         )
         self.items = items
         self.upper = upper
@@ -647,6 +702,7 @@ class HCDoubleSpinComboBox(HCMixin):
         label: str,
         units: Dict[str, float],
         label_align: str = "left",
+        auto_update=True,
     ):
         super().__init__(
             app=app,
@@ -654,6 +710,7 @@ class HCDoubleSpinComboBox(HCMixin):
             parameter=parameter,
             label=label,
             label_align=label_align,
+            auto_update=auto_update,
         )
 
         self.units = units
@@ -695,6 +752,7 @@ class HCSpinBox(HCMixin, QSpinBox):
         parameter: str,
         label: str,
         label_align: str = "left",
+        auto_update=True,
     ):
         super().__init__(
             app=app,
@@ -702,6 +760,7 @@ class HCSpinBox(HCMixin, QSpinBox):
             parameter=parameter,
             label=label,
             label_align=label_align,
+            auto_update=auto_update,
         )
 
         self.valueChanged.connect(self.value_change)
@@ -711,7 +770,7 @@ class HCSpinBox(HCMixin, QSpinBox):
         self.app.set_instrument_parameter(self.instrument, self.parameter, value)
 
     def widget_update(self, value) -> None:
-        self.setValue(float(value))
+        self.setValue(int(value))
 
 
 class HCHeader(QLabel):
@@ -720,7 +779,9 @@ class HCHeader(QLabel):
     def __init__(self, icon_name):
         super().__init__()
         self.setPixmap(load_pixmap(icon_name))
-        self.setAlignment(QtCore.Qt.AlignVCenter | QtCore.Qt.AlignHCenter)
+        self.setAlignment(
+            QtCore.Qt.AlignmentFlag.AlignVCenter | QtCore.Qt.AlignmentFlag.AlignHCenter
+        )
 
 
 class HCFixedLabel(HCMixin, QLabel):
@@ -738,8 +799,11 @@ class HCFixedLabel(HCMixin, QLabel):
         fontsize: int = 18,
         bold: bool = False,
         label_align: str = "center",
+        auto_update=True,
     ):
-        super().__init__(app=app, instrument=instrument, parameter=parameter)
+        super().__init__(
+            app=app, instrument=instrument, parameter=parameter, auto_update=auto_update
+        )
 
         self.unit = unit
         self.use_prefix = use_prefix
@@ -754,7 +818,7 @@ class HCFixedLabel(HCMixin, QLabel):
         fm = QFontMetrics(self.font())
         self.setFixedWidth(fm.width(init_label))
 
-        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         if color is not None:
             self.setStyleSheet(
                 f"color: white;background-color:{color}; padding: 5px;border: 1px solid black;"
@@ -762,11 +826,16 @@ class HCFixedLabel(HCMixin, QLabel):
 
         # Align the label
         if label_align == "right":
-            self.setAlignment(QtCore.Qt.AlignRight | QtCore.Qt.AlignVCenter)
+            self.setAlignment(
+                QtCore.Qt.AlignmentFlag.AlignRight
+                | QtCore.Qt.AlignmentFlag.AlignVCenter
+            )
         elif label_align == "left":
-            self.setAlignment(QtCore.Qt.AlignLeft | QtCore.Qt.AlignVCenter)
+            self.setAlignment(
+                QtCore.Qt.AlignmentFlag.AlignLeft | QtCore.Qt.AlignmentFlag.AlignVCenter
+            )
         elif label_align == "center":
-            self.setAlignment(QtCore.Qt.AlignCenter)
+            self.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
 
     def widget_update(self, value) -> None:
         self.setText(value)
